<?php

namespace App\Http\Controllers;

use App\Models\Categories;
use App\Models\ContactMessage;
use App\Models\Orders;
use App\Models\ProductImages;
use App\Models\Products;
use App\Models\Setting;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;


class ManageWebsiteFunctionality extends Controller
{

    public function categories()
    {
        $categories = Categories::orderBy('id', 'desc')->get();
        return view("admin.categories", compact('categories'));
    }

    public function savecategories(Request $request)
    {
        if ($request->hasFile('image')) {
            $validator = Validator::make($request->all(), [
                'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg,webp',
                'name' => 'required'
            ]);
        }

        if ($validator->fails()) {
            return back()->with('error', 'Name & Image Is Required');
        }
        $data['name'] = $request->name;

        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $data['image'] = $image_new;
        }

        Categories::create($data);
        return back()->with('success', 'Data Successfully Added !');
    }

    public function updatecategory(Request $request)
    {
        $getData = Categories::findOrFail(decrypt($request->id));

        if (isset($request->name)) {
            $getData->name = $request->name;
        }
        if ($request->hasFile('image')) {
            $validator = Validator::make($request->all(), [
                'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg,webp'
            ]);

            if ($validator->fails()) {
                return back()->with('error', 'Invalid image');
            }

            if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {

                \File::delete(public_path('admin/assets/uploads/' . $getData->image));
            }

            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $getData->image = $image_new;
        }
        $getData->save();
        return back()->with('success', 'Successfully Updated !');
    }

    public function deletecategory($id)
    {
        $getData = Categories::findOrFail(decrypt($id));
        if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {

            \File::delete(public_path('admin/assets/uploads/' . $getData->image));
        }
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function products()
    {
        $products = Products::orderBy('id', 'desc')->get();
        return view("admin.products", compact('products'));
    }

    public function add_products()
    {
        $categories = Categories::orderBy('id', 'desc')->get();
        return view("admin.add_products", compact('categories'));
    }

    public function save_products(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'price' => 'required',
            'categoryid' => 'required',
            'stock' => 'required',
            'tags' => 'required',
            'description' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All Fields Required.');
        }
        $data['name'] = $request->name;
        $data['price'] = $request->price;
        if (isset($request->cut_price) && !empty($request->cut_price)) {
            $data['cut_price'] = $request->cut_price;
        }
        $data['categoryid'] = $request->categoryid;
        $data['stock'] = $request->stock;
        $data['tags'] = $request->tags;
        $data['description'] = $request->description;
        $data['slug'] = Str::slug($request->name);
        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $data['image'] = $image_new;
        }
        $CheckSlug = Products::where('slug', Str::slug($request->name))->count();
        if ($CheckSlug > 0) {
            return back()->with('error', 'This Name is already exist .');
        }
        $productdetail = Products::create($data);

        if ($request->hasFile('MoreImages')) {
            $imagessize = sizeof($request->MoreImages);
            for ($i = 0; $i < $imagessize; $i++) {
                $image = $request->file('MoreImages')[$i];
                $image_new = time() . $image->getClientOriginalName();
                $image->move('admin/assets/uploads/', $image_new);
                $ProductData['image'] = $image_new;
                $ProductData['productid'] = $productdetail->id;;
                ProductImages::create($ProductData);
            }

        }
        return redirect()->route('admin.products')->with('success', 'Product Added Successfully');
    }

    public function delete_product($id)
    {
        $getData = Products::findOrFail(decrypt($id));
        if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {
            \File::delete(public_path('admin/assets/uploads/' . $getData->image));
        }

        if (!empty($getData->images)) {
            foreach ($getData->images as $images_image) {
                if (\File::exists(public_path('admin/assets/uploads/' . $images_image->image))) {
                    \File::delete(public_path('admin/assets/uploads/' . $images_image->image));
                }
            }
        }
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function edit_product($id)
    {
        $product = Products::findOrFail(decrypt($id));
        $categories = Categories::orderBy('id', 'desc')->get();
        return view('admin.edit_product', compact('product', 'categories'));
    }

    public function update_products(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'id' => 'required',
            'name' => 'required',
            'price' => 'required',
            'categoryid' => 'required',
            'stock' => 'required',
            'tags' => 'required',
            'description' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All Fields Required.');
        }
        $getData = Products::findOrFail($request->id);
        $getData->name = $request->name;
        $getData->price = $request->price;
        $getData->categoryid = $request->categoryid;
        $getData->stock = $request->stock;
        $getData->tags = $request->tags;
        if (isset($request->cut_price) && !empty($request->cut_price)) {
            $getData->cut_price = $request->cut_price;
        }
        if ($request->hasFile('image')) {
            $validator = Validator::make($request->all(), [
                'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg'
            ]);

            if ($validator->fails()) {
                return back()->withInput()->with('error', 'Invalid Property image');
            }
            if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {
                \File::delete(public_path('admin/assets/uploads/' . $getData->image));
            }
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $getData->image = $image_new;
        }
        $getData->update();
        return redirect()->route('admin.products')->with('success', 'Product Successfully Updated');
    }

    public function edit_product_images($id)
    {
        $product = Products::findOrFail(decrypt($id));
        return view('admin.edit_product_images', compact('product'));
    }

    public function save_product_image(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'productid' => 'required',
            'image' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All Fields Required.');
        }
        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $data['image'] = $image_new;
            $data['productid'] = $request->productid;
            ProductImages::create($data);
        }
        return redirect()->back()->with('success', 'Successfully Added.');
    }

    public function delete_product_image($id)
    {
        $getData = ProductImages::findOrFail(decrypt($id));
        if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {
            \File::delete(public_path('admin/assets/uploads/' . $getData->image));
        }
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function orders()
    {
        $active_orders = Orders::where('status', 'active')->get();
        $completed_orders = Orders::where('status', 'completed')->get();
        return view("admin.orders", compact('active_orders', 'completed_orders'));
    }

    public function mark_as_complete($id)
    {
        $order = Orders::findOrFail($id);
        $order->update(['status' => 'completed']);
        return back()->with('success', 'Successfully Updated !');
    }

    public function order_detail($id)
    {
        $order = Orders::findOrFail(decrypt($id));
        return view("admin.order_detail", compact('order'));
    }

    public function contact_messages()
    {
        $contact_messages = ContactMessage::all();
        return view("admin.contact_messages", compact('contact_messages'));
    }

    public function delete_contact_message($id)
    {
        $getData = ContactMessage::findOrFail(decrypt($id));
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

}
