<?php

namespace App\Http\Controllers;

use App\Mail\OrderConfirmation;
use App\Models\Cart;
use App\Models\Categories;
use App\Models\ContactMessage;
use App\Models\OrderDetails;
use App\Models\Orders;
use App\Models\Products;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Validator;


class WebsiteController extends Controller
{
    public function home()
    {
        $categories = Categories::all();
        $products = Products::limit(8)->get();
        return view('website.index', compact('categories', 'products'));
    }

    public function aboutus()
    {
        return view('website.aboutus');
    }

    public function thankyou($orderid)
    {
        return view('website.thankyou', compact('orderid'));
    }

    public function contactus()
    {
        return view('website.contactus');
    }

    public function save_contact_message(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'email' => 'required',
            'subject' => 'required',
            'message' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All Fields Required.');
        }
        $data['name'] = $request->name;
        $data['email'] = $request->email;
        $data['subject'] = $request->subject;
        $data['message'] = $request->message;
        ContactMessage::create($data);
        return redirect()->back()->with('success', 'Message Sent Successfully.');
    }

    public function cart()
    {
        return view('website.cart');
    }

    public function delete_cart_product($id)
    {
        $carts = Cart::findOrFail($id)->delete();
        return redirect()->back()->with('success', 'Successfully Deleted.');
    }

    public function checkout()
    {
        return view('website.checkout');
    }

    public function login()
    {
        return view('website.login');
    }

    public function signup()
    {
        return view('website.signup');
    }

    public function forgot()
    {
        return view('website.forgot');
    }

    public function save_order(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'fname' => 'required',
            'lname' => 'required',
            'email' => 'required',
            'phone' => 'required',
            'address' => 'required',
            'city' => 'required',
            'total_price_of_cart' => 'required',
            'zipcode' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All Fields Required.');
        }
        $order_idd = rand(1000, 1000000);
        $data['orderid'] = $order_idd;
        $data['fname'] = $request->fname;
        $data['lname'] = $request->lname;
        $data['email'] = $request->email;
        $data['phone'] = $request->phone;
        $data['address'] = $request->address;
        $data['city'] = $request->city;
        $data['zipcode'] = $request->zipcode;
        $data['price'] = $request->total_price_of_cart;
        $orderData = Orders::create($data);

        $carts = Cart::where('sessionid', Session::getId())->get();
        foreach ($carts as $cart) {
            $data_Detail['orderid'] = $orderData->id;
            $data_Detail['productid'] = $cart->product->id;
            $data_Detail['product_name'] = $cart->product->name;
            $data_Detail['product_price'] = $cart->product->price;
            $data_Detail['quantity'] = $cart->quantity;
            OrderDetails::create($data_Detail);
        }
        Cart::where('sessionid', Session::getId())->delete();
        $maildata = $orderData;
        $check = Mail::to($request->email)->send(new OrderConfirmation($maildata));
        return redirect()->route('thankyou', [$order_idd])->with('success', 'Order Placed.');
    }

    public function shop(Request $request)
    {
        return view('website.shop');
    }

    public function product_detail()
    {
        return view('website.product_detail');
    }

    public function blogs()
    {
        return view('website.blogs');
    }

    public function blog_detail()
    {
        return view('website.blog_detail');
    }

    public function add_to_cart_single($productid)
    {
        $check = Cart::where('sessionid', Session::getId())->where('productid', $productid)->count();
        if ($check > 0) {
            $checkProduct = Cart::where('sessionid', Session::getId())->where('productid', $productid)->first();
            $checkProduct->quantity = ($checkProduct->quantity + 1);
            $checkProduct->update();
        } else {
            $data['sessionid'] = Session::getId();
            $data['productid'] = $productid;
            $data['quantity'] = 1;
            Cart::create($data);
        }
        return redirect()->back()->with('success', 'Successfully Added.');
    }

    public function add_to_cart_multiple($quantity, $productid)
    {
        $check = Cart::where('sessionid', Session::getId())->where('productid', $productid)->count();
        if ($check > 0) {
            $checkProduct = Cart::where('sessionid', Session::getId())->where('productid', $productid)->first();
            $checkProduct->quantity = $quantity;
            $checkProduct->update();
        } else {
            $data['sessionid'] = Session::getId();
            $data['productid'] = $productid;
            $data['quantity'] = $quantity;
            Cart::create($data);
        }
        return redirect()->back()->with('success', 'Successfully Added.');
    }

    public function update_cart(Request $request)
    {
        foreach ($request->quantity as $productid => $quan) {
            $checkProduct = Cart::where('sessionid', Session::getId())->where('productid', $productid)->first();
            $checkProduct->quantity = $quan;
            $checkProduct->update();
        }
        return redirect()->back()->with('success', 'Successfully Added.');
    }

    public function mail($orderid)
    {
        $maildata = Orders::findOrFail($orderid);
        return view('website.mail', compact('maildata'));
    }
}
